@@ -14,30 +14,18 @@ support: 工具
 ├── milvus
 └── 一些常用功能函数
 """
-import csv
 import logging
 import os
 from urllib.parse import urlparse, parse_qs
 
 from dotenv import load_dotenv as __load_dotenv
 
-# 项目.跟目录
-CURRENT_DIR = os.path.abspath('.')
-# 项目.跟目录创建.cache
-CURRENT_CACHE_DIR = os.path.join(CURRENT_DIR, '.cache')
-if not os.path.isdir(CURRENT_CACHE_DIR):
-    os.mkdir(CURRENT_CACHE_DIR)
-
-try:
-    from ..env import __HUB_HOME_DIR
-except:
-    __HUB_HOME_DIR = '.winwin_hub'
+from ..env import *
 
 
 def __get_exists_file(file: str):
-    """查找目录优先级: support.py目录 > project跟目录 > HOME环境目录(~/.winwin_hub)"""
-    dirs = [os.path.dirname(os.path.abspath(__file__)), os.path.abspath('.'),
-            os.path.join(os.path.expanduser('~'), __HUB_HOME_DIR)]
+    """查找目录优先级: support.py目录 > project跟目录 > HUB目录(~/.winwin_hub) > HOME目录(~)"""
+    dirs = [os.path.dirname(os.path.abspath(__file__)), PROJECT_HOME, HUB_HOME, USER_HOME]
     for _dir in dirs:
         filepath = os.path.join(_dir, file)
         if os.path.exists(filepath):
@@ -47,7 +35,7 @@ def __get_exists_file(file: str):
 # 文件目录、项目跟目录、HOME环境目录, 加载.env环境文件
 env_file = __get_exists_file('.env')
 env_file and __load_dotenv(env_file)
-logging.info("current env file used path:[%s]" % env_file)
+logging.info("current env file path is:[%s]" % env_file)
 
 
 # MYSQL
@@ -89,62 +77,6 @@ def oss_connect(name="OSS_URI", bucket: str = ''):
                        bucket or config['bucket'])
 
 
-def oss_get_object_cache(url, bucket=None, CACHE_DIR: str = CURRENT_CACHE_DIR):
-    """下载 OSS文件到缓存目录"""
-    bucket = bucket or oss_connect()
-    cache_file = os.path.join(CACHE_DIR, os.path.basename(url))
-    if not os.path.isfile(cache_file) or os.path.getsize(cache_file) == 0:
-        parsed = urlparse(url)
-        bucket.get_object_to_file(parsed.scheme and parsed.path[1:] or parsed.path, cache_file)
-    return cache_file
-
-
-def oss_get_object_topath(url, save_path='./', bucket=None):
-    """下载 OSS文件到指定目录"""
-    bucket = bucket or oss_connect()
-    if save_path[-1] == '/' and not os.path.exists(save_path):
-        os.makedirs(save_path)
-    save_path = not os.path.basename(save_path) and os.path.join(save_path, os.path.basename(url)) or save_path
-    if not os.path.isfile(save_path) or os.path.getsize(save_path) == 0:
-        parsed = urlparse(url)
-        bucket.get_object_to_file(parsed.scheme and parsed.path[1:] or parsed.path, save_path)
-    return save_path
-
-
-def oss_get_object_stream(url, bucket=None):
-    """下载 OSS文件流"""
-    bucket = bucket or oss_connect()
-    parsed = urlparse(url)
-    oss_url = parsed.scheme and parsed.path[1:] or parsed.path
-    return bucket.get_object(oss_url).read()
-
-
-def oss_upload_object(file_url, oss_url, bucket=None):
-    """上传 本地文件到OSS"""
-    bucket = bucket or oss_connect()
-    file_name = os.path.basename(file_url)
-    parsed = urlparse(oss_url)
-    oss_url = parsed.scheme and parsed.path[1:] or parsed.path
-    print('oss_url', oss_url)
-    oss_url = not os.path.basename(oss_url) and (os.path.join(oss_url, file_name)) or oss_url
-    bucket.put_object_from_file(oss_url, file_url)
-    return '%s%s/%s' % ('oss://', bucket.bucket_name, oss_url)
-
-
-def oss_file2DF(oss_url: str, bucket=None, sep: str = None):
-    """注意文件必须是表格文件"""
-    import pandas
-    suffix = os.path.splitext(oss_url)[1]
-    content = oss_get_object_stream(oss_url, bucket)
-    if suffix == '.xlsx':
-        return pandas.read_excel(content)
-    else:
-        sep = sep or (',' if suffix == '.csv' else '\t' if suffix == '.tsv' else ',')
-        lines = str(content.decode()).strip().split('\n')
-        header, data = lines[0].split(sep), list(map(lambda x: str(x).split(sep), lines[1:]))
-        return pandas.DataFrame(data, columns=header)
-
-
 # ODPS
 ODPS_TUNNEL, ODPS_LIMIT = True, False
 
@@ -152,8 +84,9 @@ ODPS_TUNNEL, ODPS_LIMIT = True, False
 def parse_odps_uri(uri):
     parsed_uri = urlparse(uri)
     query = parse_qs(parsed_uri.query)
-    ODPS_TUNNEL = True if query.get('tunnel') is None else query.get('tunnel')[0]
-    ODPS_LIMIT = False if query.get('limit') is None else query.get('limit')[0]
+    global ODPS_TUNNEL, ODPS_LIMIT
+    ODPS_TUNNEL = True if query.get('tunnel') is None else bool(eval(query.get('tunnel')[0]))
+    ODPS_LIMIT = False if query.get('limit') is None else bool(eval(query.get('limit')[0]))
     return {
         'endpoint': '{}://{}'.format(parsed_uri.scheme, os.path.join(parsed_uri.hostname, parsed_uri.path[1:])),
         'access_id': parsed_uri.username,
@@ -168,24 +101,6 @@ def odps_connect(name="ODPS_URI"):
     return ODPS(**parse_odps_uri(os.environ[name]))
 
 
-def odps_download_with_sql(sql, save_path, connect=None, sep=','):
-    """通过SQL下载全量数据"""
-    connect = connect or odps_connect()
-    save_path = os.path.join(CURRENT_DIR, save_path)
-    if sql.endswith('.sql'):
-        with open(os.path.join(CURRENT_DIR, sql), 'r') as f:
-            fsql = f.read()
-    else:
-        fsql = sql
-    with connect.execute_sql(fsql).open_reader(tunnel=ODPS_TUNNEL, limit=ODPS_LIMIT) as reader:
-        headers = reader.schema.names
-        with open(save_path, 'w', encoding='utf8') as writefile:
-            csv_writer = csv.writer(writefile, delimiter=sep)
-            csv_writer.writerow(headers)
-            for record in reader:
-                csv_writer.writerow(dict(record).values())
-
-
 # OpenSearch
 def parse_ops_uri(uri):
     '''
@@ -207,7 +122,7 @@ def parse_ops_uri(uri):
     }
 
 
-def ops_conf(name="OPS_URI"):
+def ops_connect(name="OPS_URI"):
     """OpenSearch Conf"""
     return parse_ops_uri(os.environ[name])
 
@@ -271,6 +186,7 @@ def parse_nebula_uri(uri=None):
         'space': query.get('space') and query.get('space')[0] or '',
         'comment': query.get('comment') and query.get('comment')[0] or '',
         'heart_beat': query.get('heart_beat') and int(query.get('heart_beat')[0]) or 10,
+        'vid_str_fixed_size': query.get('vid_str_fixed_size') and int(query.get('vid_str_fixed_size')[0]) or 50,
     }
 
 
@@ -286,7 +202,8 @@ def nebula_connect(name='NEBULA_URI'):
         __nebula_pool = ConnectionPool()
         __nebula_pool.init(uri['servers'], Config())
     session = __nebula_pool.get_session(uri['username'], uri['password'])
-    session.space, session.comment, session.heart_beat = uri['space'], uri['comment'], uri['heart_beat']
+    session.space, session.comment, session.heart_beat, session.vid_str_fixed_size = uri['space'], uri['comment'], uri[
+        'heart_beat'], uri['vid_str_fixed_size']
     return session
 
 
